# eric7.eric7_post_install

Module implementing the post install logic for 'pip install'.

### Global Attributes

None

### Classes

None

### Functions

copyDesktopFile | Modify a desktop file and write it to its destination.
copyLinuxMetaData | Function to copy the meta data files.
copyMetaFile | Function to copy a file to its destination.
copyMetaFilesTree | Function to copy the files of a directory tree.
createWindowsLinks | Create Desktop and Start Menu links.
createWindowsShortcut | Create Windows shortcut.
getWinregEntry | Function to get an entry from the Windows Registry.
main | Main script orchestrating the platform dependent post installation tasks.
windowsDesktopEntries | Function to generate data for the Windows Desktop links.
windowsProgramsEntry | Function to generate the name of the Start Menu top entry.

## copyDesktopFile

copyDesktopFile(src, dst, scriptsdir)

Modify a desktop file and write it to its destination.

src
  source file name (string)
dst
  destination file name (string)
scriptsdir
  directory containing the scripts (string)

Up

## copyLinuxMetaData

copyLinuxMetaData()

Function to copy the meta data files.

Up

## copyMetaFile

copyMetaFile(srcname, dstpath, dstname)

Function to copy a file to its destination.

srcname (str)
  name of the source file
dstpath (str)
  name of the destination path
dstname (str)
  name of the destination file (without path)

Up

## copyMetaFilesTree

copyMetaFilesTree(src, dst)

Function to copy the files of a directory tree.

src
  name of the source directory
dst
  name of the destination directory

Up

## createWindowsLinks

createWindowsLinks()

Create Desktop and Start Menu links.

Up

## createWindowsShortcut

createWindowsShortcut(linkPath, targetPath, iconPath)

Create Windows shortcut.

linkPath (str)
  path of the shortcut file
targetPath (str)
  path the shortcut shall point to
iconPath (str)
  path of the icon file

Up

## getWinregEntry

getWinregEntry(name, path)

Function to get an entry from the Windows Registry.

name (str)
  variable name
path (str)
  registry path of the variable

Return:
  value of requested registry variable

Return Type:
  any

Up

## main

main()

Main script orchestrating the platform dependent post installation tasks.

Up

## windowsDesktopEntries

windowsDesktopEntries()

Function to generate data for the Windows Desktop links.

Return:
  list of tuples containing the desktop link name, the link target and the icon target

Return Type:
  list of tuples of (str, str, str)

Up

## windowsProgramsEntry

windowsProgramsEntry()

Function to generate the name of the Start Menu top entry.

Return:
  name of the Start Menu top entry

Return Type:
  str

Up